@@ -61,6 +61,7 @@ SITES = {
     'soundcloud'       : 'soundcloud',
     'ted'              : 'ted',
     'theplatform'      : 'theplatform',
+    'thvideo'          : 'thvideo',
     'tucao'            : 'tucao',
     'tudou'            : 'tudou',
     'tumblr'           : 'tumblr',
@@ -541,8 +542,7 @@ def url_save_chunked(url, filepath, bar, refer = None, is_part = False, faker =
     os.rename(temp_filepath, filepath)
 
 class SimpleProgressBar:
-    bar_size = term.get_terminal_size()[1] - 42
-    bar = '{0:>5}% ({1:>5}/{2:<5}MB) ├{3:─<' + str(bar_size) + '}┤[{4}/{5}] {6}'
+    term_size = term.get_terminal_size()[1]
 
     def __init__(self, total_size, total_pieces = 1):
         self.displayed = False
@@ -553,11 +553,19 @@ class SimpleProgressBar:
         self.speed = ''
         self.last_updated = time.time()
 
+        total_pieces_len = len(str(total_pieces))
+        # 38 is the size of all statically known size in self.bar
+        total_str = '%5s' % round(self.total_size / 1048576, 1)
+        total_str_width = max(len(total_str), 5)
+        self.bar_size = self.term_size - 27 - 2*total_pieces_len - 2*total_str_width
+        self.bar = '{:>4}%% ({:>%s}/%sMB) ├{:─<%s}┤[{:>%s}/{:>%s}] {}' % (
+            total_str_width, total_str, self.bar_size, total_pieces_len, total_pieces_len)
+
     def update(self):
         self.displayed = True
         bar_size = self.bar_size
         percent = round(self.received * 100 / self.total_size, 1)
-        if percent > 100:
+        if percent >= 100:
             percent = 100
         dots = bar_size * int(percent) // 100
         plus = int(percent) - dots // bar_size * 100
@@ -568,7 +576,7 @@ class SimpleProgressBar:
         else:
             plus = ''
         bar = '█' * dots + plus
-        bar = self.bar.format(percent, round(self.received / 1048576, 1), round(self.total_size / 1048576, 1), bar, self.current_piece, self.total_pieces, self.speed)
+        bar = self.bar.format(percent, round(self.received / 1048576, 1), bar, self.current_piece, self.total_pieces, self.speed)
         sys.stdout.write('\r' + bar)
         sys.stdout.flush()
 
@@ -576,8 +584,10 @@ class SimpleProgressBar:
         self.received += n
         time_diff = time.time() - self.last_updated
         bytes_ps = n / time_diff if time_diff else 0
-        if bytes_ps >= 1048576:
-            self.speed = '{:4.0f} MB/s'.format(bytes_ps / 1048576)
+        if bytes_ps >= 1024 ** 3:
+            self.speed = '{:4.0f} GB/s'.format(bytes_ps / 1024 ** 3)
+        elif bytes_ps >= 1024 ** 2:
+            self.speed = '{:4.0f} MB/s'.format(bytes_ps / 1024 ** 2)
         elif bytes_ps >= 1024:
             self.speed = '{:4.0f} kB/s'.format(bytes_ps / 1024)
         else:
@@ -688,11 +698,13 @@ def download_urls(urls, title, ext, total_size, output_dir='.', refer=None, merg
     if len(urls) == 1:
         url = urls[0]
         print('Downloading %s ...' % tr(output_filename))
+        bar.update()
         url_save(url, output_filepath, bar, refer = refer, faker = faker, headers = headers)
         bar.done()
     else:
         parts = []
         print('Downloading %s.%s ...' % (tr(title), ext))
+        bar.update()
         for i, url in enumerate(urls):
             filename = '%s[%02d].%s' % (title, i, ext)
             filepath = os.path.join(output_dir, filename)
